<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2023 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */

namespace Drupal\key_apigee\ConnectionTester;

use Drupal\key_apigee\Plugin\KeyType\ApigeeAuthKeyTypeInterface;

/**
 * Contract for testing connection to Apigee with data stored in keys.
 */
interface ConnectionTesterInterface {

  /**
   * Test connection with an Apigee authentication key type and a key value.
   *
   * @param \Drupal\key_apigee\Plugin\KeyType\ApigeeAuthKeyTypeInterface $key_type
   *   The Apigee authentication key type.
   * @param string $key_value
   *   The (serialized) key value.
   *
   * @throws \Drupal\key_apigee\ConnectionTester\ConnectionFailedException
   *   When connection fails with the credentials.
   */
  public function testWithKeyValue(ApigeeAuthKeyTypeInterface $key_type, string $key_value): void;

  /**
   * Test connection with an Apigee key entity.
   *
   * @param string $key_id
   *   An Apigee key entity id.
   */
  public function testWithKey(string $key_id): void;

}
