<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2023 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */

namespace Drupal\key_apigee\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element\Select;
use Drupal\key\KeyInterface;

/**
 * Provides a select form element that display Apigee keys.
 *
 * @FormElement("apigee_key_select")
 *
 * @internal This class is not part of the module's public programming API.
 */
final class ApigeeKeySelect extends Select {

  /**
   * {@inheritdoc}
   */
  public function getInfo(): array {
    $info = parent::getInfo();
    $class = static::class;

    array_unshift($info['#process'], [$class, 'processKeySelect']);

    // @todo Add filter by API gateway type option.
    return $info;
  }

  /**
   * Repopulates the select element with Apigee keys.
   *
   * @param array $element
   *   The form element to process.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   * @param array $complete_form
   *   The complete form structure.
   *
   * @return array
   *   The processed element.
   */
  public static function processKeySelect(array &$element, FormStateInterface $form_state, array &$complete_form): array {
    /** @var \Drupal\key_apigee\Repository\ApigeeKeyRepositoryInterface $repository */
    $repository = \Drupal::service('key_apigee.repository');
    $element['#options'] = array_map(static fn(KeyInterface $key): string|\Stringable => $key->label(), $repository->fetchAll());
    return $element;
  }

}
