<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2023 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */

namespace Drupal\key_apigee\Plugin\KeyInput;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\key\KeyInterface;

/**
 * Apigee X/Hybrid Authentication key input.
 *
 * @KeyInput(
 *    id = "apigee_x_auth",
 *    label = @Translation("Apigee X/Hybrid Authentication")
 *  )
 *
 * @internal This class is not part of the module's public programming API.
 */
final class ApigeeXAuthKeyInput extends ApigeeKeyInputBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    $config = parent::defaultConfiguration();
    $config['endpoint'] = 'https://apigee.googleapis.com/v1';
    $config['service_account_key'] = '';
    return $config;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);

    $form_object = $form_state->getFormObject();
    assert($form_object instanceof EntityForm);
    $key = $form_object->getEntity();
    assert($key instanceof KeyInterface);
    $definition = $key->getKeyType()->getPluginDefinition();

    $form['service_account_key'] = [
      '#type' => 'textarea',
      '#title' => $definition['multivalue']['fields']['service_account_key']['label'],
      '#description' => $definition['multivalue']['fields']['service_account_key']['description'] ?? '' ,
      '#required' => $definition['multivalue']['fields']['service_account_key']['required'] ?? FALSE,
      '#default_value' => $this->getConfiguration()['service_account_key'],
      '#rows' => '8',
    ];

    return $form;
  }

}
