<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2023 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */

namespace Drupal\key_apigee\Plugin\KeyType;

use Drupal\key\KeyInterface;
use Drupal\key\Plugin\KeyTypeInterface;
use Drupal\key\Plugin\KeyTypeMultivalueInterface;

/**
 * Marker interface for Apigee authentication key types.
 *
 * @api
 */
interface ApigeeAuthKeyTypeInterface extends KeyTypeInterface, KeyTypeMultivalueInterface {

  /**
   * Gets the API endpoint from an Apigee key entity.
   *
   * @param \Drupal\key\KeyInterface $key
   *   An Apigee key entity.
   *
   * @return string
   *   The API endpoint.
   */
  public function getEndpoint(KeyInterface $key): string;

  /**
   * Gets the organization from an Apigee key entity.
   *
   * @param \Drupal\key\KeyInterface $key
   *   An Apigee key entity.
   *
   * @return string
   *   The organization.
   */
  public function getOrganization(KeyInterface $key): string;

}
