<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2023 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */

namespace Drupal\key_apigee\Plugin\KeyType;

/**
 * Apigee Edge OAuth key type.
 *
 * @\Drupal\key_apigee\Annotation\ApigeeEdgeAuth(
 *   id = \Drupal\key_apigee\Plugin\KeyType\ApigeeEdgeOAuthKeyType::KEY_TYPE_ID,
 *   label = @Translation("Apigee Edge OAuth"),
 *   multivalue = {
 *     "fields" = {
 *       "authorization_server" = {
 *          "label" = @Translation("Authorization server"),
 *          "description" = @Translation("Leave it empty to use the default value for Apigee Public Cloud."),
 *          "required" = false
 *        },
 *        "client_id" = {
 *          "label" = @Translation("Client ID"),
 *          "description" = @Translation("Leave it empty to use the default value for Apigee Public Cloud."),
 *          "required" = false
 *        },
 *        "client_secret" = {
 *          "label" = @Translation("Client secret"),
 *          "description" = @Translation("Leave it empty to use the default value for Apigee Public Cloud or the previously saved one."),
 *          "required" = false
 *        },
 *      }
 *   }
 * )
 *
 * @internal This class is not part of the module's public programming API.
 */
final class ApigeeEdgeOAuthKeyType extends ApigeeEdgeAuthKeyTypeBase {

  public const KEY_TYPE_ID = 'apigee_edge_oauth';

}
