<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2023 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */

namespace Drupal\key_apigee\Repository;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\key\KeyInterface;
use Drupal\key_apigee\Plugin\KeyType\ApigeeEdgeBasicAuthKeyType;
use Drupal\key_apigee\Plugin\KeyType\ApigeeEdgeOAuthKeyType;
use Drupal\key_apigee\Plugin\KeyType\ApigeeXAuthKeyType;
use Drupal\key_apigee\Plugin\KeyType\ApigeeXOnGceHostedSiteAuthKeyType;

/**
 * Default Apigee key entity repository implementation.
 *
 * @internal This class is not part of the module's public programming API.
 */
final class ApigeeKeyRepository implements ApigeeKeyRepositoryInterface {

  private const APIGEE_KEY_TYPE_IDS = [
    ApigeeEdgeBasicAuthKeyType::KEY_TYPE_ID,
    ApigeeEdgeOAuthKeyType::KEY_TYPE_ID,
    ApigeeXAuthKeyType::KEY_TYPE_ID,
    ApigeeXOnGceHostedSiteAuthKeyType::KEY_TYPE_ID,
  ];

  /**
   * Constructs a new object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(private readonly EntityTypeManagerInterface $entityTypeManager) {
  }

  /**
   * {@inheritdoc}
   */
  public function fetchAll(): array {
    return $this->entityTypeManager->getStorage('key')->loadByProperties(['key_type' => self::APIGEE_KEY_TYPE_IDS]);
  }

  /**
   * {@inheritdoc}
   */
  public function getById(string $key_id): KeyInterface {
    $result = $this->entityTypeManager->getStorage('key')
      ->loadByProperties([
        'id' => $key_id,
        'key_type' => self::APIGEE_KEY_TYPE_IDS,
      ]
      );

    return $result[$key_id] ?? throw new \InvalidArgumentException(sprintf('Apigee key entity not found with "%s" ID.', $key_id));
  }

}
