<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2023 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */

namespace Drupal\key_apigee\Repository;

use Drupal\key\KeyInterface;

/**
 * Contract for Apigee key entity repositories.
 *
 * @internal This interface may get extended in upcoming releases. It becomes
 * an API afterward.
 */
interface ApigeeKeyRepositoryInterface {

  /**
   * Fetches all Apigee key entities.
   *
   * @return \Drupal\key\KeyInterface[]
   *   List of Apigee keys.
   */
  public function fetchAll(): array;

  /**
   * Gets an Apigee key entity by id.
   *
   * @return \Drupal\key\KeyInterface
   *   The Apigee key.
   *
   * @throws \InvalidArgumentException
   *   When a key not found by id.
   */
  public function getById(string $key_id): KeyInterface;

}
