<?php

declare(strict_types = 1);

/**
 * Copyright (C) 2024 PRONOVIX GROUP.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 */
namespace Drupal\key_apigee_test;

use Drupal\Core\State\StateInterface;
use Drupal\key_apigee\ConnectionTester\ConnectionFailedException;
use Drupal\key_apigee\ConnectionTester\ConnectionTesterInterface;
use Drupal\key_apigee\Plugin\KeyType\ApigeeAuthKeyTypeInterface;

/**
 * Fakes connection testing errors in tests.
 *
 * @internal This class is not part of the module's public programming API.
 *
 * @todo Add test coverage.
 */
final class FakeConnectionTester implements ConnectionTesterInterface {

  private const STATE_KEY = 'key_apigee_test.fake_connection_tester.fake_errors';

  /**
   * Constructs a new object.
   */
  public function __construct(private readonly StateInterface $state) {}

  /**
   * {@inheritdoc}
   */
  public function testWithKeyValue(ApigeeAuthKeyTypeInterface $key_type, string $key_value): void {
    if ($this->shouldFakeConnectionError()) {
      throw new ConnectionFailedException('Faked connection error.');
    }
  }

  /**
   * {@inheritdoc}
   */
  public function testWithKey(string $key_id): void {
    if ($this->shouldFakeConnectionError()) {
      throw new ConnectionFailedException('Faked connection error.');
    }
  }

  /**
   * Returns whether connection error faking is enabled or not.
   *
   * @return bool
   *   TRUE or FALSE.
   */
  private function shouldFakeConnectionError(): bool {
    return $this->state->get(self::STATE_KEY, FALSE);
  }

  /**
   * Enables connection error faking.
   */
  public function startFakingConnectionErrors(): void {
    $this->state->set(self::STATE_KEY, TRUE);
  }

  /**
   * Disables connection error faking.
   */
  public function stopFakingConnectionErrors(): void {
    $this->state->set(self::STATE_KEY, FALSE);
  }

}
